==> jooq-3.6.2-sources.jar: org/jooq/impl/WithTable.java <==
/**
 * Copyright (c) 2009-2015, Data Geekery GmbH (http://www.datageekery.com)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq.impl;

import org.jooq.Context;
import org.jooq.Record;
import org.jooq.Table;

/**
 * @author Lukas Eder
 */
class WithTable<R extends Record> extends AbstractTable<R> {

    /**
     * Generated UID
     */
    private static final long      serialVersionUID = -3905775637768497535L;

    private final AbstractTable<R> delegate;
    private final String           hint;

    WithTable(AbstractTable<R> delegate, String hint) {
        super(delegate.getName(), delegate.getSchema());

        this.delegate = delegate;
        this.hint = hint;
    }

    @Override
    public final boolean declaresTables() {
        return true;
    }

    @Override
    public final void accept(Context<?> ctx) {
        ctx.visit(delegate)
           .sql(' ').keyword("with")
           .sql(" (").sql(hint)
           .sql(')');
    }

    @Override
    public final Class<? extends R> getRecordType() {
        return delegate.getRecordType();
    }

    @Override
    public final Table<R> as(String alias) {
        return new WithTable<R>(new TableAlias<R>(delegate, alias), hint);
    }

    @Override
    public final Table<R> as(String alias, String... fieldAliases) {
        return new WithTable<R>(new TableAlias<R>(delegate, alias, fieldAliases), hint);
    }

    @Override
    final Fields<R> fields0() {
        return delegate.fields0();
    }
}

==> jooq-3.11.9-sources.jar: org/jooq/impl/WithTable.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq.impl;

import static org.jooq.impl.Keywords.K_WITH;

import org.jooq.Context;
import org.jooq.Name;
import org.jooq.Record;
import org.jooq.Table;

/**
 * @author Lukas Eder
 */
final class WithTable<R extends Record> extends AbstractTable<R> {

    /**
     * Generated UID
     */
    private static final long      serialVersionUID = -3905775637768497535L;

    private final AbstractTable<R> delegate;
    private final String           hint;

    WithTable(AbstractTable<R> delegate, String hint) {
        super(delegate.getName(), delegate.getSchema());

        this.delegate = delegate;
        this.hint = hint;
    }

    @Override
    public final boolean declaresTables() {
        return true;
    }

    @Override
    public final void accept(Context<?> ctx) {
        ctx.visit(delegate)
           .sql(' ').visit(K_WITH)
           .sql(" (").sql(hint)
           .sql(')');
    }

    @Override
    public final Class<? extends R> getRecordType() {
        return delegate.getRecordType();
    }

    @Override
    public final Table<R> as(Name alias) {
        return new WithTable<R>(new TableAlias<R>(delegate, alias), hint);
    }

    @Override
    public final Table<R> as(Name alias, Name... fieldAliases) {
        return new WithTable<R>(new TableAlias<R>(delegate, alias, fieldAliases), hint);
    }

    @Override
    final Fields<R> fields0() {
        return delegate.fields0();
    }
}
